Extract model information from a survivalmodels object
extract_model.RdThis function extracts model information from a neural network trained with
the survivalmodels package.
Usage
extract_model(x, path = NULL, num_basehazard = 200L)
# S3 method for class 'coxtime'
extract_model(x, path = NULL, num_basehazard = 200L)
# S3 method for class 'deephit'
extract_model(x, path = NULL, ...)
# S3 method for class 'deepsurv'
extract_model(x, path = NULL, num_basehazard = 200L)Arguments
- x
A
survivalmodelsobject, i.e.,survivalmodels::deephit,survivalmodels::coxtime, orsurvivalmodels::deepsurv.- path
A string specifying the path to save the extracted model. If
NULL, the model is not saved. Default isNULL.- num_basehazard
An integer specifying the number of points of the baseline hazard to compute. Default is
200L. This argument is only used forcoxtimeanddeepsurvmodels.- ...
Unused arguments.